Module blaxel.core.client.models.public_ip
==========================================

Classes
-------

`PublicIp(description: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, ipv_4_cidrs: blaxel.core.client.types.Unset | list[str] = <blaxel.core.client.types.Unset object>, ipv_6_cidrs: blaxel.core.client.types.Unset | list[str] = <blaxel.core.client.types.Unset object>)`
:   Attributes:
        description (Union[Unset, str]): Description of the region/location
        ipv_4_cidrs (Union[Unset, list[str]]): List of public ipv4 addresses
        ipv_6_cidrs (Union[Unset, list[str]]): List of public ipv6 addresses
    
    Method generated by attrs for class PublicIp.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `description: blaxel.core.client.types.Unset | str`
    :

    `ipv_4_cidrs: blaxel.core.client.types.Unset | list[str]`
    :

    `ipv_6_cidrs: blaxel.core.client.types.Unset | list[str]`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :